@@ -16,6 +16,55 @@
 import yaml
 
 deprecated_node_types = {
+    'cloudify.azure.nodes.resources.Azure':
+        'cloudify.nodes.azure.resources.Azure',
+    'cloudify.azure.nodes.compute.ManagedCluster':
+        'cloudify.nodes.azure.compute.ManagedCluster',
+    'cloudify.azure.nodes.compute.ContainerService':
+        'cloudify.nodes.azure.compute.ContainerService',
+    'cloudify.azure.nodes.network.LoadBalancer.Probe':
+        'cloudify.nodes.azure.network.LoadBalancer.Probe',
+    'cloudify.azure.nodes.network.LoadBalancer.BackendAddressPool':
+        'cloudify.nodes.azure.network.LoadBalancer.BackendAddressPool',
+    'cloudify.azure.nodes.network.LoadBalancer.IncomingNATRule':
+        'cloudify.nodes.azure.network.LoadBalancer.IncomingNATRule',
+    'cloudify.azure.nodes.network.LoadBalancer.Rule':
+        'cloudify.nodes.azure.network.LoadBalancer.Rule',
+    'cloudify.azure.nodes.network.LoadBalancer':
+        'cloudify.nodes.azure.network.LoadBalancer',
+    'cloudify.azure.nodes.compute.VirtualMachineExtension':
+        'cloudify.nodes.azure.compute.VirtualMachineExtension',
+    'cloudify.azure.nodes.PublishingUser':
+        'cloudify.nodes.azure.PublishingUser',
+    'cloudify.azure.nodes.WebApp':
+        'cloudify.nodes.azure.WebApp',
+    'cloudify.azure.nodes.Plan':
+        'cloudify.nodes.azure.Plan',
+    'cloudify.azure.nodes.compute.WindowsVirtualMachine':
+        'cloudify.nodes.azure.compute.WindowsVirtualMachine',
+    'cloudify.azure.nodes.compute.AvailabilitySet':
+        'cloudify.nodes.azure.compute.AvailabilitySet',
+    'cloudify.azure.nodes.network.Route':
+        'cloudify.nodes.azure.network.Route',
+    'cloudify.azure.nodes.network.NetworkSecurityRule':
+        'cloudify.nodes.azure.network.NetworkSecurityRule',
+    'cloudify.azure.nodes.network.RouteTable':
+        'cloudify.nodes.azure.network.RouteTable',
+
+    'cloudify.azure.nodes.network.Subnet':
+        'cloudify.nodes.azure.network.Subnet',
+    'cloudify.azure.nodes.compute.VirtualMachine':
+        'cloudify.nodes.azure.compute.VirtualMachine',
+    'cloudify.azure.nodes.network.NetworkInterfaceCard':
+        'cloudify.nodes.azure.network.NetworkInterfaceCard',
+    'cloudify.azure.nodes.network.NetworkSecurityGroup':
+        'cloudify.nodes.azure.network.NetworkSecurityGroup',
+    'cloudify.azure.nodes.network.IPConfiguration':
+        'cloudify.nodes.azure.network.IPConfiguration',
+    'cloudify.azure.nodes.network.VirtualNetwork':
+        'cloudify.nodes.azure.network.VirtualNetwork',
+    'cloudify.azure.nodes.network.PublicIPAddress':
+        'cloudify.nodes.azure.network.PublicIPAddress',
     'cloudify.azure.nodes.ResourceGroup':
         'cloudify.nodes.azure.ResourceGroup',
     'cloudify.azure.nodes.storage.StorageAccount':
@@ -445,8 +494,8 @@ REQUIRED_RELATIONSHIPS = {
             'cloudify.relationships.depends_on',
     },
     'cloudify.nodes.aws.ec2.Instances': {
-        'cloudify.nodes.aws.ec2.Image':
-            'cloudify.relationships.depends_on',
+        # 'cloudify.nodes.aws.ec2.Image':
+        #     'cloudify.relationships.depends_on',
         'cloudify.nodes.aws.ec2.Interface':
             'cloudify.relationships.depends_on',
     },
